==> google-cloud-aiplatform-0.5.0.tar.gz: google-cloud-aiplatform-0.5.0/google/cloud/aiplatform/v1/schema/trainingjob/definition_v1/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .automl_image_classification import (
    AutoMlImageClassification,
    AutoMlImageClassificationInputs,
    AutoMlImageClassificationMetadata,
)
from .automl_image_object_detection import (
    AutoMlImageObjectDetection,
    AutoMlImageObjectDetectionInputs,
    AutoMlImageObjectDetectionMetadata,
)
from .automl_image_segmentation import (
    AutoMlImageSegmentation,
    AutoMlImageSegmentationInputs,
    AutoMlImageSegmentationMetadata,
)
from .export_evaluated_data_items_config import ExportEvaluatedDataItemsConfig
from .automl_tables import (
    AutoMlTables,
    AutoMlTablesInputs,
    AutoMlTablesMetadata,
)
from .automl_text_classification import (
    AutoMlTextClassification,
    AutoMlTextClassificationInputs,
)
from .automl_text_extraction import (
    AutoMlTextExtraction,
    AutoMlTextExtractionInputs,
)
from .automl_text_sentiment import (
    AutoMlTextSentiment,
    AutoMlTextSentimentInputs,
)
from .automl_video_action_recognition import (
    AutoMlVideoActionRecognition,
    AutoMlVideoActionRecognitionInputs,
)
from .automl_video_classification import (
    AutoMlVideoClassification,
    AutoMlVideoClassificationInputs,
)
from .automl_video_object_tracking import (
    AutoMlVideoObjectTracking,
    AutoMlVideoObjectTrackingInputs,
)

__all__ = (
    "AutoMlImageClassification",
    "AutoMlImageClassificationInputs",
    "AutoMlImageClassificationMetadata",
    "AutoMlImageObjectDetection",
    "AutoMlImageObjectDetectionInputs",
    "AutoMlImageObjectDetectionMetadata",
    "AutoMlImageSegmentation",
    "AutoMlImageSegmentationInputs",
    "AutoMlImageSegmentationMetadata",
    "ExportEvaluatedDataItemsConfig",
    "AutoMlTables",
    "AutoMlTablesInputs",
    "AutoMlTablesMetadata",
    "AutoMlTextClassification",
    "AutoMlTextClassificationInputs",
    "AutoMlTextExtraction",
    "AutoMlTextExtractionInputs",
    "AutoMlTextSentiment",
    "AutoMlTextSentimentInputs",
    "AutoMlVideoActionRecognition",
    "AutoMlVideoActionRecognitionInputs",
    "AutoMlVideoClassification",
    "AutoMlVideoClassificationInputs",
    "AutoMlVideoObjectTracking",
    "AutoMlVideoObjectTrackingInputs",
)

==> google-cloud-aiplatform-1.18.2.tar.gz: google-cloud-aiplatform-1.18.2/google/cloud/aiplatform/v1/schema/trainingjob/definition_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .automl_image_classification import (
    AutoMlImageClassification,
    AutoMlImageClassificationInputs,
    AutoMlImageClassificationMetadata,
)
from .automl_image_object_detection import (
    AutoMlImageObjectDetection,
    AutoMlImageObjectDetectionInputs,
    AutoMlImageObjectDetectionMetadata,
)
from .automl_image_segmentation import (
    AutoMlImageSegmentation,
    AutoMlImageSegmentationInputs,
    AutoMlImageSegmentationMetadata,
)
from .automl_tables import (
    AutoMlTables,
    AutoMlTablesInputs,
    AutoMlTablesMetadata,
)
from .automl_text_classification import (
    AutoMlTextClassification,
    AutoMlTextClassificationInputs,
)
from .automl_text_extraction import (
    AutoMlTextExtraction,
    AutoMlTextExtractionInputs,
)
from .automl_text_sentiment import (
    AutoMlTextSentiment,
    AutoMlTextSentimentInputs,
)
from .automl_video_action_recognition import (
    AutoMlVideoActionRecognition,
    AutoMlVideoActionRecognitionInputs,
)
from .automl_video_classification import (
    AutoMlVideoClassification,
    AutoMlVideoClassificationInputs,
)
from .automl_video_object_tracking import (
    AutoMlVideoObjectTracking,
    AutoMlVideoObjectTrackingInputs,
)
from .export_evaluated_data_items_config import (
    ExportEvaluatedDataItemsConfig,
)

__all__ = (
    "AutoMlImageClassification",
    "AutoMlImageClassificationInputs",
    "AutoMlImageClassificationMetadata",
    "AutoMlImageObjectDetection",
    "AutoMlImageObjectDetectionInputs",
    "AutoMlImageObjectDetectionMetadata",
    "AutoMlImageSegmentation",
    "AutoMlImageSegmentationInputs",
    "AutoMlImageSegmentationMetadata",
    "AutoMlTables",
    "AutoMlTablesInputs",
    "AutoMlTablesMetadata",
    "AutoMlTextClassification",
    "AutoMlTextClassificationInputs",
    "AutoMlTextExtraction",
    "AutoMlTextExtractionInputs",
    "AutoMlTextSentiment",
    "AutoMlTextSentimentInputs",
    "AutoMlVideoActionRecognition",
    "AutoMlVideoActionRecognitionInputs",
    "AutoMlVideoClassification",
    "AutoMlVideoClassificationInputs",
    "AutoMlVideoObjectTracking",
    "AutoMlVideoObjectTrackingInputs",
    "ExportEvaluatedDataItemsConfig",
)
